#
# See the file "LICENSE" for the full license governing this code.
#
#
# This function determins the CIS db_version to use for this call. It uses the following algorithmn:
# 
# 1. Use te specified version for this database
# 2. Use a generic specified version for all databases
# 3. Check if fact ora_version is set. If not, return an undef
# 4. Use the version based on the version of the database
#
Puppet::Functions.create_function('ora_cis::default_db_version') do
  dispatch :default_db_version do
    param 'String[1]', :sid
  end

  def default_db_version(sid)
    #
    # When a version is specified, use it.
    #
    value = lookup_setting('db_version', nil)
    return value if value
    #
    # When the version fact is available, use it
    #
    return nil unless closure_scope.include?('ora_version')
    db_version = db_version(closure_scope['ora_version'], sid).first
    case db_version
    when /^12\..*/
      'db12c'
    when /^18\..*/
      'db18c'
    when /^19\..*/
      'db19c'
    else
      fail "Database version #{db_version} not recognised"
    end
  end

  def lookup_setting(sid, default_value)
    call_function('ora_cis::lookup_setting', sid, default_value )
  end

  def db_version(data, sid)
    call_function('ora_config::on_sid', data, sid)
  end

end
  