#
# See the file "LICENSE" for the full license governing this code.
#
# This function determins the CIS default doc_version based on the db_version.It uses the following algorithmn:
# 
# 1. Use the specified version for this database
# 2. Use a generic specified version for all databases
# 3. Use the latest version available for thos db_version
#
Puppet::Functions.create_function('ora_cis::default_doc_version') do
    dispatch :default_doc_version do
      param 'Optional[String[1]]', :db_version
    end
  
    def default_doc_version(db_version)
      #
      # When a version is specified, use it.
      #
      value = lookup_setting('doc_version', nil)
      return value if value
      return nil if db_version.nil?
      #
      # The array of versions is sorted from newest on top down to the latest. So the first one
      # in the array is the lastest and we need that one.
      #
      valid_combinations[db_version].first
    end
  
    def lookup_setting(sid, default_value)
      call_function('ora_cis::lookup_setting', sid, default_value )
    end
  
    def valid_combinations
      @valid_combinations ||= call_function('lookup', 'ora_cis::valid_combinations', data_type('Hash'), 'first', nil)
    end
  
    def data_type(string)
      parser = Puppet::Pops::Types::TypeParser.singleton
      parser.parse(string)
    end

  end
    