#
# See the file "LICENSE" for the full license governing this code.
#
#
# Validate if the specified db_version and doc_version is an
# existing combination. If not give a readable error message that shows
# available versions
#
Puppet::Functions.create_function('ora_cis::validate_versions') do
  dispatch :validate_versions do
    param 'String', :db_version
    param 'String', :doc_version
  end

  def validate_versions(db_version, doc_version)
    valid_doc_versions = valid_combinations[db_version]
    raise Puppet::Error.new("db_version '#{db_version}' is not known and/or supported.\n Valid versions are #{valid_db_versions}") if valid_doc_versions.nil?
    raise Puppet::Error.new("doc_version '#{doc_version}' is not known and/or supported for  db_version '#{db_version}'.\n Valid versions for db_version '#{db_version}' are #{valid_doc_versions.join(',')}") unless valid_doc_versions.include?(doc_version)
  end

  def valid_db_versions
    valid_combinations.keys.join(',')
  end

  def valid_combinations
    @valid_combinations ||= call_function('lookup', 'ora_cis::valid_combinations', data_type('Hash'), 'first', nil)
  end

  def data_type(string)
    parser = Puppet::Pops::Types::TypeParser.singleton
    parser.parse(string)
  end

end
  