#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::admin_restrictions_is_set_to_on
#
# @summary The `admin_restrictions_<listener_name>` setting in the `listener.
# ora` file can
# require that any attempted real-time alteration of the parameters in the
# listener via the set command file be refused unless the `listener.ora` file is
# manually altered, then restarted by a privileged user.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::admin_restrictions_is_set_to_on: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::admin_restrictions_is_set_to_on::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `admin_restrictions_is_set_to_on` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# test
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 2.1.3
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 2.1.3
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 2.1.2
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::admin_restrictions_is_set_to_on()
{
  alert('Specified CIS rule is not yet automatically enforced.')
}
