#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::all_sample_data_and_users_have_been_removed
#
# @summary Oracle sample schemas can be used to create sample users
# (`BI`,`HR`,`IX`,`OE`,`PM`,`SCOTT`,`SH`), with well-known default passwords, particular views,
# and procedures/functions, in addition to tables and fictitious data. The sample
# schemas should be removed. 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::all_sample_data_and_users_have_been_removed: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::all_sample_data_and_users_have_been_removed::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_sample_data_and_users_have_been_removed` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 4.2
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 4.2
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 4.2
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
#--++--
#
define ora_cis::controls::all_sample_data_and_users_have_been_removed(
  Array $exclude = ora_cis::lookup_setting('exclude', []),
){
  $sid = $title
  ora_cis_setup { "all_sample_data_and_users_have_been_removed on ${sid}":
    ensure => 'present'
  }
  $schemas = [
    'BI',
    'HR',
    'OE',
    'PM',
    'IX',
    'SH',
    'SCOTT',
  ]

  $users_to_check = $schemas - $exclude
  $users_to_check.each |$user| {
    $full_name = "${user}@${sid}"
    ora_user{$full_name:
      ensure  => 'absent',
    }
  }
}

