#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes
#
# @summary The Oracle database `WITH_ADMIN` privilege allows the designated user to grant
# another user the same privileges. Unauthorized grantees should not have that
# privilege.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 5.2.2
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 5.2.2
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 5.2.2
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
#--++--
#
define ora_cis::controls::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes(
  Array $exclude = ora_cis::lookup_setting('exclude', []),
){

  $sid = $title
  $control_excludes = ora_config::on_sid($::ora_maintained_users_roles, $sid)
  $all_exclude_controls = $control_excludes + $exclude + $::ora_apex_users
  $users_to_check = ora_config::on_sid($::ora_accounts_with_admin_grants, $sid) - $all_exclude_controls

  ora_cis_setup { "dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes on ${sid}":
    ensure => 'present',
  }
  $users_to_check.each |$username| {
    $full_name = "Ora_user[${username}@${sid}]grants_with_admin"
    resource_value { $full_name:
      value        => [],
      allow_create => true,
    }
  }
}
