#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::delete_catalog_role_is_revoked_from_unauthorized_grantee
#
# @summary **THIS ROLE IS DEPRECATED IN V12.
# **
# The Oracle database `DELETE_CATALOG_ROLE` provide
# `DELETE` privileges for the records in the system's audit table (`AUD$`). Unauthorized grantees 
# should not have that role.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::delete_catalog_role_is_revoked_from_unauthorized_grantee: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::delete_catalog_role_is_revoked_from_unauthorized_grantee::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `delete_catalog_role_is_revoked_from_unauthorized_grantee` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 5.3.1
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::delete_catalog_role_is_revoked_from_unauthorized_grantee(
  Array $exclude_users = ora_cis::lookup_setting('exclude_users', []),
  Array $exclude_roles = ora_cis::lookup_setting('exclude_roles', []),
){
  $sid = $title
  $all_exclude_users = ora_config::on_sid($::ora_maintained_users, $sid) + $exclude_users
  $all_exclude_roles = ora_config::on_sid($::ora_maintained_roles, $sid) + $exclude_roles
  
  ora_cis_setup { "delete_catalog_role_is_revoked_from_unauthorized_grantee on ${sid}":
    ensure => 'present',
  }
  -> ora_cis::internal::revoke_user_rights{"DELETE_CATALOG_ROLE@${sid}":
    exclude => $exclude_users,
  }
  -> ora_cis::internal::revoke_role_rights{"DELETE_CATALOG_ROLE@${sid}":
    exclude => $exclude_roles,
  }
}
