#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::extproc_is_not_present_in_listener_ora
#
# @summary `extproc` should be removed from the `listener.
# ora` to mitigate the risk that OS
# libraries can be invoked by the Oracle instance.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::extproc_is_not_present_in_listener_ora: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::extproc_is_not_present_in_listener_ora::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `extproc_is_not_present_in_listener_ora` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 2.1.2
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 2.1.2
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 2.1.1
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::extproc_is_not_present_in_listener_ora()
{
  alert('Specified CIS rule is not yet automatically enforced.')
}
