#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::os_roles_is_set_to_false
#
# @summary The `os_roles` setting permits externally created groups to be applied to database management.
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::os_roles_is_set_to_false: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::os_roles_is_set_to_false::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `os_roles_is_set_to_false` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 2.2.5
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 2.2.5
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 2.2.4
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::os_roles_is_set_to_false()
{
  $sid = $title
  ora_cis_setup { "os_roles_is_set_to_false on ${sid}":
    ensure => 'present'
  }
  -> ora_cis::internal::parameter { "OS_ROLES@${sid}":
    value => 'FALSE',
  }
}

