#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::remote_listener_is_empty
#
# @summary The `remote_listener` setting determines whether or not a valid listener can be
# established on a system separate from the database instance. This setting should
# be empty unless the organization specifically needs a valid listener on a
# separate system or on nodes running Oracle RAC instances.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::remote_listener_is_empty: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::remote_listener_is_empty::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `remote_listener_is_empty` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 2.2.6
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 2.2.6
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 2.2.5
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::remote_listener_is_empty()
{
  $sid = $title
  ora_cis_setup { "remote_listener_is_empty on ${sid}":
    ensure => 'present'
  }
  -> ora_cis::internal::parameter { "REMOTE_LISTENER@${sid}":
    ensure => 'absent',
    value  => '',
  }
}
