#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::sec_max_failed_login_attempts_is_3_or_less
#
# @summary The `SEC_MAX_FAILED_LOGIN_ATTEMPTS` parameter determines how many failed login
# attempts are allowed before Oracle closes the login connection.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::sec_max_failed_login_attempts_is_3_or_less: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::sec_max_failed_login_attempts_is_3_or_less::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sec_max_failed_login_attempts_is_3_or_less` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 2.2.12
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 2.2.11
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 2.2.10
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Integer[0, 3]] preferred_value
#    The preferred value to use.
#    Some rules allow multiple values. The rule implement a default value, but when you want an other value, you can use this parameter.
#
#--++--
#
define ora_cis::controls::sec_max_failed_login_attempts_is_3_or_less(
  Integer[0,3] $preferred_value = ora_cis::lookup_setting('preferred_value', 3),
)
{
  $sid = $title
  ora_cis_setup { "sec_max_failed_login_attempts_is_3_or_less_nopdb on ${sid}":
    ensure => 'present'
  }
  -> ora_cis::internal::parameter { "SEC_MAX_FAILED_LOGIN_ATTEMPTS@${sid}":
    value =>  $preferred_value,
  }
}
