#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::sec_protocol_error_trace_action_is_set_to_log
#
# @summary The `SEC_PROTOCOL_ERROR_TRACE_ACTION` setting determines the Oracle's server's
# logging response level to bad/malformed packets received from the client by
# generating `ALERT`, `LOG`, or `TRACE` levels of detail in the log files. This
# setting should have a value of `LOG` unless the organization has a compelling
# reason to use a different value because `LOG` should cause the necessary
# information to be logged. Setting the value as `TRACE` can generate an enormous
# amount of log output and should be reserved for debugging only.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::sec_protocol_error_trace_action_is_set_to_log: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::sec_protocol_error_trace_action_is_set_to_log::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sec_protocol_error_trace_action_is_set_to_log` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 2.2.14
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 2.2.13
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 2.2.12
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::sec_protocol_error_trace_action_is_set_to_log()
{
  $sid = $title
  ora_cis_setup { "sec_protocol_error_trace_action_is_set_to_log on ${sid}":
    ensure => 'present'
  }
  -> ora_cis::internal::parameter { "SEC_PROTOCOL_ERROR_TRACE_ACTION@${sid}":
    value => 'LOG',
  }
}
