#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::secure_register_is_set_to_tcps_or_ipc
#
# @summary The `SECURE_REGISTER_<listener_name>` setting specifies the protocols used to
# connect to the TNS listener. Each setting should have a value of either TCPS or
# IPC based on the needs for its protocol.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::secure_register_is_set_to_tcps_or_ipc: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::secure_register_is_set_to_tcps_or_ipc::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_register_is_set_to_tcps_or_ipc` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 2.1.4
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 2.1.4
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::secure_register_is_set_to_tcps_or_ipc()
{
  alert('Specified CIS rule is not yet automatically enforced.')
}
