#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::sys_user_mig_has_been_dropped
#
# @summary The table `sys.
# user$mig` is created during migration and contains the Oracle
# password hashes before the migration starts. This table should be dropped.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::sys_user_mig_has_been_dropped: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::sys_user_mig_has_been_dropped::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sys_user_mig_has_been_dropped` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 4.5
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 4.5
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 4.5
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::sys_user_mig_has_been_dropped()
{
  $sid = $title
  ora_cis_setup { "sys_user_mig_has_been_dropped on ${sid}":
    ensure => 'present',
  }
  -> ora_exec{"drop table SYS.USER\$MIG@${sid}":
    onlyif => "SELECT * FROM ALL_TABLES WHERE OWNER='SYS' AND TABLE_NAME='USER\$MIG'",
  }
}
